# we don't want to provide private python extension libs
%define _exclude_files_from_autoprov %{python_sitearch}/.*\\.so\\|%{python3_sitearch}/.*\\.so

Summary:	ReportLab library to create PDF documents using Python
Name:		python-reportlab
Version:	3.3.0
Release:	%mkrel 1
URL:		http://www.reportlab.org/
Source0:	https://pypi.python.org/packages/source/r/reportlab/reportlab-%{version}.tar.gz
Patch0:		reportlab-%{version}-font-locations.patch
License:	BSD
Group:		Publishing
BuildRequires:	pkgconfig(python)
BuildRequires:	python-pillow
BuildRequires:	freetype-devel
Requires:	fonts-ttf-dejavu
Requires:	python-pillow

%description
ReportLab is a library that lets you directly create documents in
Adobe's Portable Document Format (PDF) using the Python programming
language.

ReportLab library creates PDF based on graphics commands without
intervening steps. It's therefore extremely fast, and flexible (since
you're using a full-blown programming language).

Sample use cases are:

  * Dynamic PDF generation on the web
  * High-volume corporate reporting and database publishing
  * As embeddable print engine for other applications, including a
    'report language' so that users can customize their own reports.
  * As 'build system' for complex documents with charts, tables and text
    such as management accounts, statistical reports and scientific papers
  * from XML to PDF in one step

%package -n python3-reportlab
Summary:	ReportLab library to create PDF documents using Python 3
Group:		Development/Python
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-pillow
Requires:	fonts-ttf-dejavu
Requires:	python3-pillow

%description -n python3-reportlab
ReportLab is a library that lets you directly create documents in
Adobe's Portable Document Format (PDF) using the Python programming
language.

ReportLab library creates PDF based on graphics commands without
intervening steps. It's therefore extremely fast, and flexible (since
you're using a full-blown programming language).

%package docs
Summary:	Documentation files for %{name}
Requires:	%{name} = %{version}-%{release}
Group:		Publishing
License:	BSD

%description docs
Contains the documentation for ReportLab.

%prep
%setup -q -n reportlab-%{version}
%patch0 -p0
# clean up hashbangs from libraries
find src -name '*.py' | xargs sed -i -e '/^#!\//d'
cp -a . %{py3dir} 

%build
pushd %{py3dir}
%py3_build
popd

%py2_build
# a bit of a horrible hack due to a chicken-and-egg problem. The docs
# require reportlab, which isn't yet installed, but is at least built.
PYTHONPATH="`pwd`/`ls -d build/lib*`" %{__python} docs/genAll.py


%install
pushd %{py3dir}
%py3_install
rm -rf %{buildroot}%{python3_sitearch}/reportlab/fonts
popd

%py2_install
# Remove bundled fonts
rm -rf %{buildroot}%{python_sitearch}/reportlab/fonts

%files
%doc README.txt CHANGES.md LICENSE.txt 
%{python2_sitearch}/reportlab
%{python2_sitearch}/reportlab*.egg-info

%files -n python3-reportlab
%doc README.txt CHANGES.md LICENSE.txt 
%{python3_sitearch}/reportlab
%{python3_sitearch}/reportlab*.egg-info

%files docs
%doc docs/*.pdf demos tools



%changelog
* Mon Feb 22 2016 philippem <philippem> 3.3.0-1.mga6
+ Revision: 976113
- update to 3.3.0

* Tue Feb 16 2016 umeabot <umeabot> 3.2.0-4.mga6
+ Revision: 962434
- Mageia 6 Mass Rebuild

* Sat Oct 10 2015 tv <tv> 3.2.0-3.mga6
+ Revision: 889125
+ rebuild (emptylog)

* Sat Oct 10 2015 tv <tv> 3.2.0-2.mga6
+ Revision: 888970
- rebuild for python 3.5

* Tue Sep 08 2015 philippem <philippem> 3.2.0-1.mga6
+ Revision: 874235
- update to 3.2.0

* Wed Oct 15 2014 umeabot <umeabot> 3.1.8-5.mga5
+ Revision: 740309
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.1.8-4.mga5
+ Revision: 726909
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.1.8-3.mga5
+ Revision: 688307
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 3.1.8-2.mga5
+ Revision: 628989
- Rebuild for new Python

* Thu Apr 24 2014 philippem <philippem> 3.1.8-1.mga5
+ Revision: 617694
- update to 3.1.8

* Mon Mar 17 2014 philippem <philippem> 3.0-1.mga5
+ Revision: 604488
- update to 3.0, add Python3

* Tue Oct 22 2013 umeabot <umeabot> 2.7-4.mga4
+ Revision: 544237
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2.7-3.mga4
+ Revision: 499287
- Rebuild to add different pythonegg provides for python 2 and 3

  + philippem <philippem>
    - cleaning spec

* Tue Jul 02 2013 philippem <philippem> 2.7-1.mga4
+ Revision: 449800
- new version 2.7

* Sun Jan 13 2013 umeabot <umeabot> 2.5-6.mga3
+ Revision: 379435
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Feb 17 2011 philippem <philippem> 2.5-5.mga1
+ Revision: 52985
- fix missing group for docs #31

* Fri Feb 11 2011 philippem <philippem> 2.5-4.mga1
+ Revision: 49993
- fix linkage
- imported package python-reportlab

